@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import os
 
@@ -40,7 +40,8 @@ from qgis.core import (QgsGeometry,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterExtent,
                        QgsProcessingParameterCrs,
-                       QgsProcessingParameterFeatureSink)
+                       QgsProcessingParameterFeatureSink,
+                       QgsProcessingParameterDefinition)
 from qgis.PyQt.QtCore import QVariant
 
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
@@ -72,9 +73,12 @@ class FindProjection(QgisAlgorithm):
                                                               self.tr('Input layer')))
         extent_parameter = QgsProcessingParameterExtent(self.TARGET_AREA,
                                                         self.tr('Target area for layer'))
-        #extent_parameter.skip_crs_check = True
         self.addParameter(extent_parameter)
-        self.addParameter(QgsProcessingParameterCrs(self.TARGET_AREA_CRS, 'Target area CRS'))
+
+        # deprecated
+        crs_param = QgsProcessingParameterCrs(self.TARGET_AREA_CRS, 'Target area CRS', optional=True)
+        crs_param.setFlags(crs_param.flags() | QgsProcessingParameterDefinition.FlagHidden)
+        self.addParameter(crs_param)
 
         self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT,
                                                             self.tr('CRS candidates')))
@@ -91,7 +95,11 @@ class FindProjection(QgisAlgorithm):
             raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
 
         extent = self.parameterAsExtent(parameters, self.TARGET_AREA, context)
-        target_crs = self.parameterAsCrs(parameters, self.TARGET_AREA_CRS, context)
+        target_crs = self.parameterAsExtentCrs(parameters, self.TARGET_AREA, context)
+        if self.TARGET_AREA_CRS in parameters:
+            c = self.parameterAsCrs(parameters, self.TARGET_AREA_CRS, context)
+            if c.isValid():
+                target_crs = c
 
         target_geom = QgsGeometry.fromRect(extent)
 
